@@ -78,6 +78,7 @@ class SAHP(Recording):
             )
 
         if self.voltage is not None:
+            self.set_autothreshold()
             self.compute_spikecount(efel_settings)
 
         self.export_attr = ["ton", "tmid", "tmid2", "toff", "tend", "amp",
@@ -123,6 +124,16 @@ class SAHP(Recording):
         amp2_value = numpy.median(smooth_current[self.tmid : self.tmid2]) - self.hypamp
         self.set_amplitudes_ecode("amp2", config_data, reader_data, amp2_value)
 
+        if config_data.get("tend", None) is None:
+            self.tend = len(self.t) * self.dt
+        else:
+            self.tend = config_data["tend"]
+
+        self.ton = self.t[int(round(self.ton))]
+        self.toff = self.t[int(round(self.toff))]
+        self.tmid = self.t[int(round(self.tmid))]
+        self.tmid2 = self.t[int(round(self.tmid2))]
+
     def step_detection(self, current, config_data, reader_data):
 
         # Set the threshold to detect the step
@@ -190,7 +201,7 @@ class SAHP(Recording):
 
         # Check for some common step detection failures when the current
         # is constant.
-        if self.ton > self.toff or self.ton > self.tend or \
+        if self.ton >= self.toff or self.ton >= self.tend or \
                 self.toff > self.tend or self.tmid == self.ton \
                 or self.tmid2 == self.toff:
 
@@ -209,9 +220,9 @@ class SAHP(Recording):
         needed to reconstruct the array"""
 
         self.dt = t[1]
-
-        if "ton" in config_data and "tmid" in config_data:
-            self.set_timing_ecode(["ton", "tmid", "tmid2", "toff"], config_data)
+        required = ["ton", "tmid", "tmid2", "toff"]
+        if all(r in config_data for r in required):
+            self.set_timing_ecode(required, config_data)
             self.compute_amp(current, config_data, reader_data)
         else:
             self.step_detection(current, config_data, reader_data)
