@@ -73,6 +73,7 @@ class Step(Recording):
             )
 
         if self.voltage is not None:
+            self.set_autothreshold()
             self.compute_spikecount(efel_settings)
 
         self.export_attr = ["ton", "toff", "tend", "amp", "hypamp", "dt",
@@ -173,7 +174,7 @@ class Step(Recording):
 
         # Check for some common step detection failures when the current
         # is constant.
-        if self.ton > self.toff or self.ton > self.tend or \
+        if self.ton >= self.toff or self.ton >= self.tend or \
                 self.toff > self.tend:
 
             self.ton = 0.
